#!/usr/bin/env bash
#
# Create : 2022-07-11
# Description: 気象庁予報取得のための地域情報定義と確認関数

if [ $(basename $0) != $(basename ${BASH_SOURCE}) ]; then
    # jma3, jma7 から読み込まれる時: 天気を取得する対象地域をここに記述しておく
    _area="${_area-東京都}"            # 対象地域名:データ取得には無関係
    _area_code="${_area_code-130000}"  # 対象地域コード
    _area3f="${_area3f-東京地方}"      # 予報対象地域
    _area3t="${_area3t-東京}"          # 気温取得対象地域
    return
else # 以下本スクリプトを単独で実行 
# Description: jmaの前に 目的の観測地点から得られる情報を確認する
# Usage: "$0 [-s] [地域コード]"
#      1. [エリアコード一覧](https://www.jma.go.jp/bosai/common/const/area.json)
#         にある観測地域全てに対して [default]
#      2. 指定した 地域コード に対して
#      https://www.jma.go.jp/bosai/forecast/data/forecast/${area_code}.json
#      に含む、地域名称(.areas.area.name) と 地域コード(.areas.area.code) を列挙

    jma_forecast() { # 天気: 結果は、jma_forecast.jsonとして保存しておく
        area_code=${1-130000}
        # area_code 460040 の要素はないので404が返ってくる curl -f でフェイルセーフにしておく
        curl -m 3 -f -s https://www.jma.go.jp/bosai/forecast/data/forecast/${area_code}.json
    }

    areas() {
        if [ -z "$1" ]; then
            curl -s https://www.jma.go.jp/bosai/common/const/area.json |
            jq '.offices | to_entries | .[] | .key, .value.name' |
            awk ' NR%2{o=$0} !(NR%2){printf("%s\t%s\n", $0, o) }' | tr -d \"
        else
            echo "_" "${1-130000}"
        fi
    }

    get_areas_from_focast() {
        declare -A s3 a3
        s3=([0]="予報" [1]="降水確率" [2]="気温")
        a3=([0]="area3f" [2]="area3t")

        local a c
        areas $1 |
        while read a c ; do
            printf "area=%s code=%s\n" $a $c
            _forecast=$( jma_forecast $c )
            for i in 0 1 2 ; do
                echo .
                echo "${a3[$i]}: .[0].[$i] 3日間の${s3[$i]}"
                jq ".[0].timeSeries[$i].areas[].area | .code, .name " <<<$_forecast | tr -d \" |
                awk ' NR%2{o=$0} !(NR%2){printf("%s\t%s\n", $0, o) }' | tr -d \"
            done
            echo "--------------------------"
        done
    }
    
    while getopts : OPT ; do
      case $OPT in
        *) # [ "$OPT" = '?' -a "${OPTARG}" = '?' ] &&  usage_exit
            echo "$0 [-s] [地域コード]"
            exit ;;
      esac
    done
    shift $((OPTIND - 1))
    get_areas_from_focast $1 # 地域コード=$1
fi
