#!/usr/bin/env bash
#
# Description: 気象庁から情報を取得する
# Create: 2022-07-07

LANG=ja_JP.UTF-8
LC_TIME=ja_JP.UTF-8
timeout=3

area_code() { # 地域・観測所の名称、コード
    curl -m ${timeout} -s https://www.jma.go.jp/bosai/common/const/area.json
}

forecast() { # 天気: 結果は、jma_forecast.jsonとして保存しておく
    area_code=${1-130000}
    curl -m ${timeout} -s https://www.jma.go.jp/bosai/forecast/data/forecast/${area_code}.json
}

overview_forecast() { # 天気概況（明後日まで）: jma_overview_forecast.json
    area_code=${1-130000}
    curl -m ${timeout} -s https://www.jma.go.jp/bosai/forecast/data/overview_forecast/${area_code}.json
}

overview_week() { # 天気予報（明後日まで・週間）: jma_overview_forecast.json
    area_code=${1-130000}
    curl -m ${timeout} -s https://www.jma.go.jp/bosai/forecast/data/overview_week/${area_code}.json
}

amedas() { # アメダス
    curl -m ${timeout} -s https://www.jma.go.jp/bosai/amedas/const/amedastable.json
}

amedas_map() { # アメダスマップ
    local d="${1-$( date +"%Y%m%d%H")}0000"
    curl -m ${timeout} -s https://www.jma.go.jp/bosai/amedas/data/map/${d}.json
    #echo "https://www.jma.go.jp/bosai/amedas/data/map/yyyyMMddHHmm00.json"
    #echo "https://www.jma.go.jp/bosai/amedas/data/map/${d}.json"
}

common() { # コンテンツ種別: jma_common.json
    curl -m ${timeout} -s https://www.jma.go.jp/bosai/common/const/contents.json
}

usage_exit() {
    echo "$0 [area_code forecast overview_forecast overview_week amedas amedas_map common]"
    echo '    Hack me: amedas_map()は、日時を引数に取れるが、CLIでは指定できない。'
    exit 1
}

while getopts :qj OPT ; do
  case $OPT in
    q) quiet=1 ;;
    j) parse_json=1 ;;
    *) usage_exit ;;
  esac
done
shift $((OPTIND - 1))

if [ -z "$1" ]; then
    usage_exit
else
    for i; do
        [ -z "$quiet" ] && echo "$i"
        if [ -z "$parse_json" ]; then
            $i
        else
            $i | jq .
        fi
        echo
    done
fi

